# -*- coding: utf-8 -*-

from django.conf import settings

from rest_framework import viewsets, status
from rest_framework.decorators import action
from rest_framework.response import Response

from thx.api.views import ThuxViewMixin
from thx.role.core.views import ThuxRoleViewSetMixin

from . import serializers
from ... import models


# CARRIAGE
class CarriageViewSet(ThuxRoleViewSetMixin, ThuxViewMixin, viewsets.ModelViewSet):
    queryset = models.Carriage.objects.all()
    serializer_class = serializers.CarriageSerializer

    @action(methods=['patch'], detail=True)
    def enable(self, request, **filters):
        return super().partial_update(request)

    @action(methods=['patch'], detail=True)
    def disable(self, request, **filters):
        return super().partial_update(request)


# DELIVERY
class DeliveryViewSet(ThuxRoleViewSetMixin, ThuxViewMixin, viewsets.ModelViewSet):
    queryset = models.Delivery.objects.all()
    serializer_class = serializers.DeliverySerializer

    @action(methods=['patch'], detail=True)
    def enable(self, request, **filters):
        return super().partial_update(request)

    @action(methods=['patch'], detail=True)
    def disable(self, request, **filters):
        return super().partial_update(request)

    @action(methods=['get'], detail=False, url_path='transport-by-options')
    def transport_by_options(self, request, **filters):
        return Response(data=settings.CARRIAGE_TRANSPORTBY_DEF, status=status.HTTP_200_OK)
